@@ -18,24 +18,16 @@ Tests for the API /ports/ methods.
 import datetime
 
 import mock
-from oslo_config import cfg
-from oslo_utils import timeutils
-from oslo_utils import uuidutils
-import six
-from six.moves import http_client
+from oslo.config import cfg
+from oslo.utils import timeutils
 from six.moves.urllib import parse as urlparse
 from testtools.matchers import HasLength
-from wsme import types as wtypes
 
-from ironic.api.controllers import base as api_base
-from ironic.api.controllers import v1 as api_v1
-from ironic.api.controllers.v1 import port as api_port
-from ironic.api.controllers.v1 import utils as api_utils
 from ironic.common import exception
+from ironic.common import utils
 from ironic.conductor import rpcapi
-from ironic.tests.api import base as test_api_base
+from ironic.tests.api import base
 from ironic.tests.api import utils as apiutils
-from ironic.tests import base
 from ironic.tests.db import utils as dbutils
 from ironic.tests.objects import utils as obj_utils
 
@@ -45,20 +37,12 @@ from ironic.tests.objects import utils as obj_utils
 def post_get_test_port(**kw):
     port = apiutils.port_post_data(**kw)
     node = dbutils.get_test_node()
+    del port['node_id']
     port['node_uuid'] = kw.get('node_uuid', node['uuid'])
     return port
 
 
-class TestPortObject(base.TestCase):
-
-    def test_port_init(self):
-        port_dict = apiutils.port_post_data(node_id=None)
-        del port_dict['extra']
-        port = api_port.Port(**port_dict)
-        self.assertEqual(wtypes.Unset, port.extra)
-
-
-class TestListPorts(test_api_base.FunctionalTest):
+class TestListPorts(base.FunctionalTest):
 
     def setUp(self):
         super(TestListPorts, self).setUp()
@@ -69,7 +53,7 @@ class TestListPorts(test_api_base.FunctionalTest):
         self.assertEqual([], data['ports'])
 
     def test_one(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
+        port = obj_utils.create_test_port(self.context)
         data = self.get_json('/ports')
         self.assertEqual(port.uuid, data['ports'][0]["uuid"])
         self.assertNotIn('extra', data['ports'][0])
@@ -78,7 +62,7 @@ class TestListPorts(test_api_base.FunctionalTest):
         self.assertNotIn('node_id', data['ports'][0])
 
     def test_get_one(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
+        port = obj_utils.create_test_port(self.context)
         data = self.get_json('/ports/%s' % port.uuid)
         self.assertEqual(port.uuid, data['uuid'])
         self.assertIn('extra', data)
@@ -86,54 +70,8 @@ class TestListPorts(test_api_base.FunctionalTest):
         # never expose the node_id
         self.assertNotIn('node_id', data)
 
-    def test_get_one_custom_fields(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
-        fields = 'address,extra'
-        data = self.get_json(
-            '/ports/%s?fields=%s' % (port.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MAX_VER)})
-        # We always append "links"
-        self.assertItemsEqual(['address', 'extra', 'links'], data)
-
-    def test_get_collection_custom_fields(self):
-        fields = 'uuid,extra'
-        for i in range(3):
-            obj_utils.create_test_port(self.context,
-                                       node_id=self.node.id,
-                                       uuid=uuidutils.generate_uuid(),
-                                       address='52:54:00:cf:2d:3%s' % i)
-
-        data = self.get_json(
-            '/ports?fields=%s' % fields,
-            headers={api_base.Version.string: str(api_v1.MAX_VER)})
-
-        self.assertEqual(3, len(data['ports']))
-        for port in data['ports']:
-            # We always append "links"
-            self.assertItemsEqual(['uuid', 'extra', 'links'], port)
-
-    def test_get_custom_fields_invalid_fields(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
-        fields = 'uuid,spongebob'
-        response = self.get_json(
-            '/ports/%s?fields=%s' % (port.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MAX_VER)},
-            expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
-        self.assertEqual('application/json', response.content_type)
-        self.assertIn('spongebob', response.json['error_message'])
-
-    def test_get_custom_fields_invalid_api_version(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
-        fields = 'uuid,extra'
-        response = self.get_json(
-            '/ports/%s?fields=%s' % (port.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MIN_VER)},
-            expect_errors=True)
-        self.assertEqual(http_client.NOT_ACCEPTABLE, response.status_int)
-
     def test_detail(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
+        port = obj_utils.create_test_port(self.context)
         data = self.get_json('/ports/detail')
         self.assertEqual(port.uuid, data['ports'][0]["uuid"])
         self.assertIn('extra', data['ports'][0])
@@ -142,31 +80,28 @@ class TestListPorts(test_api_base.FunctionalTest):
         self.assertNotIn('node_id', data['ports'][0])
 
     def test_detail_against_single(self):
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
+        port = obj_utils.create_test_port(self.context)
         response = self.get_json('/ports/%s/detail' % port.uuid,
                                  expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
 
     def test_many(self):
         ports = []
         for id_ in range(5):
-            port = obj_utils.create_test_port(
-                self.context, node_id=self.node.id,
-                uuid=uuidutils.generate_uuid(),
-                address='52:54:00:cf:2d:3%s' % id_)
+            port = obj_utils.create_test_port(self.context,
+                                            id=id_,
+                                            uuid=utils.generate_uuid(),
+                                            address='52:54:00:cf:2d:3%s' % id_)
             ports.append(port.uuid)
         data = self.get_json('/ports')
         self.assertEqual(len(ports), len(data['ports']))
 
         uuids = [n['uuid'] for n in data['ports']]
-        six.assertCountEqual(self, ports, uuids)
+        self.assertEqual(ports.sort(), uuids.sort())
 
-    def _test_links(self, public_url=None):
-        cfg.CONF.set_override('public_endpoint', public_url, 'api')
-        uuid = uuidutils.generate_uuid()
-        obj_utils.create_test_port(self.context,
-                                   uuid=uuid,
-                                   node_id=self.node.id)
+    def test_links(self):
+        uuid = utils.generate_uuid()
+        obj_utils.create_test_port(self.context, id=1, uuid=uuid)
         data = self.get_json('/ports/%s' % uuid)
         self.assertIn('links', data.keys())
         self.assertEqual(2, len(data['links']))
@@ -175,28 +110,13 @@ class TestListPorts(test_api_base.FunctionalTest):
             bookmark = l['rel'] == 'bookmark'
             self.assertTrue(self.validate_link(l['href'], bookmark=bookmark))
 
-        if public_url is not None:
-            expected = [{'href': '%s/v1/ports/%s' % (public_url, uuid),
-                         'rel': 'self'},
-                        {'href': '%s/ports/%s' % (public_url, uuid),
-                         'rel': 'bookmark'}]
-            for i in expected:
-                self.assertIn(i, data['links'])
-
-    def test_links(self):
-        self._test_links()
-
-    def test_links_public_url(self):
-        self._test_links(public_url='http://foo')
-
     def test_collection_links(self):
         ports = []
         for id_ in range(5):
-            port = obj_utils.create_test_port(
-                self.context,
-                node_id=self.node.id,
-                uuid=uuidutils.generate_uuid(),
-                address='52:54:00:cf:2d:3%s' % id_)
+            port = obj_utils.create_test_port(self.context,
+                                            id=id_,
+                                            uuid=utils.generate_uuid(),
+                                            address='52:54:00:cf:2d:3%s' % id_)
             ports.append(port.uuid)
         data = self.get_json('/ports/?limit=3')
         self.assertEqual(3, len(data['ports']))
@@ -208,11 +128,10 @@ class TestListPorts(test_api_base.FunctionalTest):
         cfg.CONF.set_override('max_limit', 3, 'api')
         ports = []
         for id_ in range(5):
-            port = obj_utils.create_test_port(
-                self.context,
-                node_id=self.node.id,
-                uuid=uuidutils.generate_uuid(),
-                address='52:54:00:cf:2d:3%s' % id_)
+            port = obj_utils.create_test_port(self.context,
+                                            id=id_,
+                                            uuid=utils.generate_uuid(),
+                                            address='52:54:00:cf:2d:3%s' % id_)
             ports.append(port.uuid)
         data = self.get_json('/ports')
         self.assertEqual(3, len(data['ports']))
@@ -224,8 +143,8 @@ class TestListPorts(test_api_base.FunctionalTest):
         address_template = "aa:bb:cc:dd:ee:f%d"
         for id_ in range(3):
             obj_utils.create_test_port(self.context,
-                                       node_id=self.node.id,
-                                       uuid=uuidutils.generate_uuid(),
+                                       id=id_,
+                                       uuid=utils.generate_uuid(),
                                        address=address_template % id_)
 
         target_address = address_template % 1
@@ -239,117 +158,22 @@ class TestListPorts(test_api_base.FunctionalTest):
         self.assertThat(data['ports'], HasLength(0))
 
     def test_port_by_address_invalid_address_format(self):
-        obj_utils.create_test_port(self.context, node_id=self.node.id)
+        obj_utils.create_test_port(self.context)
         invalid_address = 'invalid-mac-format'
         response = self.get_json('/ports?address=%s' % invalid_address,
                                  expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertIn(invalid_address, response.json['error_message'])
 
-    def test_sort_key(self):
-        ports = []
-        for id_ in range(3):
-            port = obj_utils.create_test_port(
-                self.context,
-                node_id=self.node.id,
-                uuid=uuidutils.generate_uuid(),
-                address='52:54:00:cf:2d:3%s' % id_)
-            ports.append(port.uuid)
-        data = self.get_json('/ports?sort_key=uuid')
-        uuids = [n['uuid'] for n in data['ports']]
-        self.assertEqual(sorted(ports), uuids)
-
-    def test_sort_key_invalid(self):
-        invalid_keys_list = ['foo', 'extra']
-        for invalid_key in invalid_keys_list:
-            response = self.get_json('/ports?sort_key=%s' % invalid_key,
-                                     expect_errors=True)
-            self.assertEqual(http_client.BAD_REQUEST, response.status_int)
-            self.assertEqual('application/json', response.content_type)
-            self.assertIn(invalid_key, response.json['error_message'])
-
-    @mock.patch.object(api_utils, 'get_rpc_node')
-    def test_get_all_by_node_name_ok(self, mock_get_rpc_node):
-        # GET /v1/ports specifying node_name - success
-        mock_get_rpc_node.return_value = self.node
-        for i in range(5):
-            if i < 3:
-                node_id = self.node.id
-            else:
-                node_id = 100000 + i
-            obj_utils.create_test_port(self.context,
-                                       node_id=node_id,
-                                       uuid=uuidutils.generate_uuid(),
-                                       address='52:54:00:cf:2d:3%s' % i)
-        data = self.get_json("/ports?node=%s" % 'test-node',
-                             headers={api_base.Version.string: '1.5'})
-        self.assertEqual(3, len(data['ports']))
-
-    @mock.patch.object(api_utils, 'get_rpc_node')
-    def test_get_all_by_node_uuid_and_name(self, mock_get_rpc_node):
-        # GET /v1/ports specifying node and uuid - should only use node_uuid
-        mock_get_rpc_node.return_value = self.node
-        obj_utils.create_test_port(self.context, node_id=self.node.id)
-        self.get_json('/ports/detail?node_uuid=%s&node=%s' %
-                      (self.node.uuid, 'node-name'))
-        mock_get_rpc_node.assert_called_once_with(self.node.uuid)
-
-    @mock.patch.object(api_utils, 'get_rpc_node')
-    def test_get_all_by_node_name_not_supported(self, mock_get_rpc_node):
-        # GET /v1/ports specifying node_name - name not supported
-        mock_get_rpc_node.side_effect = (
-            exception.InvalidUuidOrName(name=self.node.uuid))
-        for i in range(3):
-            obj_utils.create_test_port(self.context,
-                                       node_id=self.node.id,
-                                       uuid=uuidutils.generate_uuid(),
-                                       address='52:54:00:cf:2d:3%s' % i)
-        data = self.get_json("/ports?node=%s" % 'test-node',
-                             expect_errors=True)
-        self.assertEqual(0, mock_get_rpc_node.call_count)
-        self.assertEqual(http_client.NOT_ACCEPTABLE, data.status_int)
-
-    @mock.patch.object(api_utils, 'get_rpc_node')
-    def test_detail_by_node_name_ok(self, mock_get_rpc_node):
-        # GET /v1/ports/detail specifying node_name - success
-        mock_get_rpc_node.return_value = self.node
-        port = obj_utils.create_test_port(self.context, node_id=self.node.id)
-        data = self.get_json('/ports/detail?node=%s' % 'test-node',
-                             headers={api_base.Version.string: '1.5'})
-        self.assertEqual(port.uuid, data['ports'][0]['uuid'])
-        self.assertEqual(self.node.uuid, data['ports'][0]['node_uuid'])
-
-    @mock.patch.object(api_utils, 'get_rpc_node')
-    def test_detail_by_node_name_not_supported(self, mock_get_rpc_node):
-        # GET /v1/ports/detail specifying node_name - name not supported
-        mock_get_rpc_node.side_effect = (
-            exception.InvalidUuidOrName(name=self.node.uuid))
-        obj_utils.create_test_port(self.context, node_id=self.node.id)
-        data = self.get_json('/ports/detail?node=%s' % 'test-node',
-                             expect_errors=True)
-        self.assertEqual(0, mock_get_rpc_node.call_count)
-        self.assertEqual(http_client.NOT_ACCEPTABLE, data.status_int)
-
-    @mock.patch.object(api_port.PortsController, '_get_ports_collection')
-    def test_detail_with_incorrect_api_usage(self, mock_gpc):
-        # GET /v1/ports/detail specifying node and node_uuid.  In this case
-        # we expect the node_uuid interface to be used.
-        self.get_json('/ports/detail?node=%s&node_uuid=%s' %
-                      ('test-node', self.node.uuid))
-        mock_gpc.assert_called_once_with(self.node.uuid, mock.ANY, mock.ANY,
-                                         mock.ANY, mock.ANY, mock.ANY,
-                                         mock.ANY)
-
 
 @mock.patch.object(rpcapi.ConductorAPI, 'update_port')
-class TestPatch(test_api_base.FunctionalTest):
+class TestPatch(base.FunctionalTest):
 
     def setUp(self):
         super(TestPatch, self).setUp()
         self.node = obj_utils.create_test_node(self.context)
-        self.port = obj_utils.create_test_port(self.context,
-                                               node_id=self.node.id)
+        self.port = obj_utils.create_test_port(self.context)
 
         p = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for')
         self.mock_gtf = p.start()
@@ -365,7 +189,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'value': 'bar',
                                      'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(extra, response.json['extra'])
 
         kargs = mock_upd.call_args[0][1]
@@ -381,19 +205,19 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'add'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertIn(self.port.address, response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
     def test_update_not_found(self, mock_upd):
-        uuid = uuidutils.generate_uuid()
+        uuid = utils.generate_uuid()
         response = self.patch_json('/ports/%s' % uuid,
                                    [{'path': '/extra/foo',
                                      'value': 'bar',
                                      'op': 'add'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -406,7 +230,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'value': address,
                                      'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(address, response.json['address'])
         self.assertTrue(mock_upd.called)
 
@@ -420,9 +244,9 @@ class TestPatch(test_api_base.FunctionalTest):
                                    [{'path': '/address',
                                      'value': address,
                                      'op': 'replace'}],
-                                   expect_errors=True)
+                                     expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.CONFLICT, response.status_code)
+        self.assertEqual(409, response.status_code)
         self.assertTrue(response.json['error_message'])
         self.assertTrue(mock_upd.called)
 
@@ -432,59 +256,59 @@ class TestPatch(test_api_base.FunctionalTest):
     def test_replace_node_uuid(self, mock_upd):
         mock_upd.return_value = self.port
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_uuid',
-                                     'value': self.node.uuid,
-                                     'op': 'replace'}])
+                             [{'path': '/node_uuid',
+                               'value': self.node.uuid,
+                               'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
 
     def test_add_node_uuid(self, mock_upd):
         mock_upd.return_value = self.port
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_uuid',
-                                     'value': self.node.uuid,
-                                     'op': 'add'}])
+                             [{'path': '/node_uuid',
+                               'value': self.node.uuid,
+                               'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
 
     def test_add_node_id(self, mock_upd):
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_id',
-                                     'value': '1',
-                                     'op': 'add'}],
-                                   expect_errors=True)
+                             [{'path': '/node_id',
+                               'value': '1',
+                               'op': 'add'}],
+                               expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertFalse(mock_upd.called)
 
     def test_replace_node_id(self, mock_upd):
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_id',
-                                     'value': '1',
-                                     'op': 'replace'}],
-                                   expect_errors=True)
+                             [{'path': '/node_id',
+                               'value': '1',
+                               'op': 'replace'}],
+                               expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertFalse(mock_upd.called)
 
     def test_remove_node_id(self, mock_upd):
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_id',
-                                     'op': 'remove'}],
-                                   expect_errors=True)
+                             [{'path': '/node_id',
+                               'op': 'remove'}],
+                               expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertFalse(mock_upd.called)
 
     def test_replace_non_existent_node_uuid(self, mock_upd):
         node_uuid = '12506333-a81c-4d59-9987-889ed5f8687b'
         response = self.patch_json('/ports/%s' % self.port.uuid,
-                                   [{'path': '/node_uuid',
-                                     'value': node_uuid,
-                                     'op': 'replace'}],
-                                   expect_errors=True)
+                             [{'path': '/node_uuid',
+                               'value': node_uuid,
+                               'op': 'replace'}],
+                             expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertIn(node_uuid, response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -506,7 +330,7 @@ class TestPatch(test_api_base.FunctionalTest):
         response = self.patch_json('/ports/%s' % self.port.uuid,
                                    patch)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(extra, response.json['extra'])
         kargs = mock_upd.call_args[0][1]
         self.assertEqual(extra, kargs.extra)
@@ -524,7 +348,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                    [{'path': '/extra/foo1',
                                      'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(extra, response.json['extra'])
         kargs = mock_upd.call_args[0][1]
         self.assertEqual(extra, kargs.extra)
@@ -535,7 +359,7 @@ class TestPatch(test_api_base.FunctionalTest):
         response = self.patch_json('/ports/%s' % self.port.uuid,
                                    [{'path': '/extra', 'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual({}, response.json['extra'])
         kargs = mock_upd.call_args[0][1]
         self.assertEqual(extra, kargs.extra)
@@ -550,7 +374,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'remove'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -560,7 +384,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'remove'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -573,7 +397,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'value': address,
                                      'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(address, response.json['address'])
         self.assertTrue(mock_upd.called)
         kargs = mock_upd.call_args[0][1]
@@ -586,7 +410,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'add'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -602,7 +426,7 @@ class TestPatch(test_api_base.FunctionalTest):
         response = self.patch_json('/ports/%s' % self.port.uuid,
                                    patch)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(extra, response.json['extra'])
         kargs = mock_upd.call_args[0][1]
         self.assertEqual(extra, kargs.extra)
@@ -612,7 +436,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                    [{'path': '/uuid',
                                      'op': 'remove'}],
                                    expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
@@ -624,7 +448,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'replace'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['error_message'])
         self.assertFalse(mock_upd.called)
 
@@ -637,13 +461,13 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'value': address,
                                      'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(address.lower(), response.json['address'])
         kargs = mock_upd.call_args[0][1]
         self.assertEqual(address.lower(), kargs.address)
 
 
-class TestPost(test_api_base.FunctionalTest):
+class TestPost(base.FunctionalTest):
 
     def setUp(self):
         super(TestPost, self).setUp()
@@ -655,12 +479,12 @@ class TestPost(test_api_base.FunctionalTest):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
         response = self.post_json('/ports', pdict)
-        self.assertEqual(http_client.CREATED, response.status_int)
+        self.assertEqual(201, response.status_int)
         result = self.get_json('/ports/%s' % pdict['uuid'])
         self.assertEqual(pdict['uuid'], result['uuid'])
         self.assertFalse(result['updated_at'])
         return_created_at = timeutils.parse_isotime(
-            result['created_at']).replace(tzinfo=None)
+                            result['created_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_created_at)
         # Check location header
         self.assertIsNotNone(response.location)
@@ -685,22 +509,26 @@ class TestPost(test_api_base.FunctionalTest):
         response = self.post_json('/ports', pdict)
         result = self.get_json('/ports/%s' % response.json['uuid'])
         self.assertEqual(pdict['address'], result['address'])
-        self.assertTrue(uuidutils.is_uuid_like(result['uuid']))
+        self.assertTrue(utils.is_uuid_like(result['uuid']))
 
     def test_create_port_valid_extra(self):
-        pdict = post_get_test_port(extra={'str': 'foo', 'int': 123,
-                                          'float': 0.1, 'bool': True,
-                                          'list': [1, 2], 'none': None,
-                                          'dict': {'cat': 'meow'}})
+        pdict = post_get_test_port(extra={'foo': 123})
         self.post_json('/ports', pdict)
         result = self.get_json('/ports/%s' % pdict['uuid'])
         self.assertEqual(pdict['extra'], result['extra'])
 
+    def test_create_port_invalid_extra(self):
+        pdict = post_get_test_port(extra={'foo': 0.123})
+        response = self.post_json('/ports', pdict, expect_errors=True)
+        self.assertEqual(400, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertTrue(response.json['error_message'])
+
     def test_create_port_no_mandatory_field_address(self):
         pdict = post_get_test_port()
         del pdict['address']
         response = self.post_json('/ports', pdict, expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -708,14 +536,14 @@ class TestPost(test_api_base.FunctionalTest):
         pdict = post_get_test_port()
         del pdict['node_uuid']
         response = self.post_json('/ports', pdict, expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
     def test_create_port_invalid_addr_format(self):
         pdict = post_get_test_port(address='invalid-format')
         response = self.post_json('/ports', pdict, expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -732,7 +560,7 @@ class TestPost(test_api_base.FunctionalTest):
         hyphensMAC = colonsMAC.replace(':', '-')
         pdict['address'] = hyphensMAC
         response = self.post_json('/ports', pdict, expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -740,7 +568,7 @@ class TestPost(test_api_base.FunctionalTest):
         pdict = post_get_test_port(node_uuid='invalid-format')
         response = self.post_json('/ports', pdict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['error_message'])
 
     def test_node_uuid_to_node_id_mapping(self):
@@ -752,55 +580,51 @@ class TestPost(test_api_base.FunctionalTest):
 
     def test_create_port_node_uuid_not_found(self):
         pdict = post_get_test_port(
-            node_uuid='1a1a1a1a-2b2b-3c3c-4d4d-5e5e5e5e5e5e')
+                              node_uuid='1a1a1a1a-2b2b-3c3c-4d4d-5e5e5e5e5e5e')
         response = self.post_json('/ports', pdict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['error_message'])
 
     def test_create_port_address_already_exist(self):
         address = 'AA:AA:AA:11:22:33'
         pdict = post_get_test_port(address=address)
         self.post_json('/ports', pdict)
-        pdict['uuid'] = uuidutils.generate_uuid()
+        pdict['uuid'] = utils.generate_uuid()
         response = self.post_json('/ports', pdict, expect_errors=True)
-        self.assertEqual(http_client.CONFLICT, response.status_int)
+        self.assertEqual(409, response.status_int)
         self.assertEqual('application/json', response.content_type)
         error_msg = response.json['error_message']
         self.assertTrue(error_msg)
         self.assertIn(address, error_msg.upper())
 
 
-@mock.patch.object(rpcapi.ConductorAPI, 'destroy_port')
-class TestDelete(test_api_base.FunctionalTest):
+class TestDelete(base.FunctionalTest):
 
     def setUp(self):
         super(TestDelete, self).setUp()
         self.node = obj_utils.create_test_node(self.context)
-        self.port = obj_utils.create_test_port(self.context,
-                                               node_id=self.node.id)
+        self.port = obj_utils.create_test_port(self.context)
 
-        gtf = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for')
-        self.mock_gtf = gtf.start()
-        self.mock_gtf.return_value = 'test-topic'
-        self.addCleanup(gtf.stop)
+    def test_delete_port_byid(self):
+        self.delete('/ports/%s' % self.port.uuid)
+        response = self.get_json('/ports/%s' % self.port.uuid,
+                                 expect_errors=True)
+        self.assertEqual(404, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertIn(self.port.uuid, response.json['error_message'])
 
-    def test_delete_port_byaddress(self, mock_dpt):
+    def test_delete_port_byaddress(self):
         response = self.delete('/ports/%s' % self.port.address,
                                expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertIn(self.port.address, response.json['error_message'])
 
-    def test_delete_port_byid(self, mock_dpt):
-        self.delete('/ports/%s' % self.port.uuid, expect_errors=True)
-        self.assertTrue(mock_dpt.called)
-
-    def test_delete_port_node_locked(self, mock_dpt):
+    def test_delete_port_node_locked(self):
         self.node.reserve(self.context, 'fake', self.node.uuid)
-        mock_dpt.side_effect = exception.NodeLocked(node='fake-node',
-                                                    host='fake-host')
-        ret = self.delete('/ports/%s' % self.port.uuid, expect_errors=True)
-        self.assertEqual(http_client.CONFLICT, ret.status_code)
-        self.assertTrue(ret.json['error_message'])
-        self.assertTrue(mock_dpt.called)
+        response = self.delete('/ports/%s' % self.port.uuid,
+                               expect_errors=True)
+        self.assertEqual(409, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertIn(self.node.uuid, response.json['error_message'])
