@@ -18,22 +18,27 @@
 import datetime
 
 import mock
-from oslo_utils import timeutils
+from oslo.utils import timeutils
 
 from ironic.common import exception
+from ironic.db import api as dbapi
 from ironic.tests.db import base
 from ironic.tests.db import utils
 
 
 class DbConductorTestCase(base.DbTestCase):
 
+    def setUp(self):
+        super(DbConductorTestCase, self).setUp()
+        self.dbapi = dbapi.get_instance()
+
     def test_register_conductor_existing_fails(self):
         c = utils.get_test_conductor()
         self.dbapi.register_conductor(c)
         self.assertRaises(
-            exception.ConductorAlreadyRegistered,
-            self.dbapi.register_conductor,
-            c)
+                exception.ConductorAlreadyRegistered,
+                self.dbapi.register_conductor,
+                c)
 
     def test_register_conductor_override(self):
         c = utils.get_test_conductor()
@@ -52,19 +57,19 @@ class DbConductorTestCase(base.DbTestCase):
     def test_get_conductor_not_found(self):
         self._create_test_cdr()
         self.assertRaises(
-            exception.ConductorNotFound,
-            self.dbapi.get_conductor,
-            'bad-hostname')
+                exception.ConductorNotFound,
+                self.dbapi.get_conductor,
+                'bad-hostname')
 
     def test_unregister_conductor(self):
         c = self._create_test_cdr()
         self.dbapi.unregister_conductor(c.hostname)
         self.assertRaises(
-            exception.ConductorNotFound,
-            self.dbapi.unregister_conductor,
-            c.hostname)
+                exception.ConductorNotFound,
+                self.dbapi.unregister_conductor,
+                c.hostname)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_touch_conductor(self, mock_utcnow):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
@@ -82,9 +87,9 @@ class DbConductorTestCase(base.DbTestCase):
         # it will only update existing ones
         self._create_test_cdr()
         self.assertRaises(
-            exception.ConductorNotFound,
-            self.dbapi.touch_conductor,
-            'bad-hostname')
+                exception.ConductorNotFound,
+                self.dbapi.touch_conductor,
+                'bad-hostname')
 
     def test_touch_offline_conductor(self):
         # Ensure that a conductor's periodic heartbeat task can make the
@@ -92,9 +97,9 @@ class DbConductorTestCase(base.DbTestCase):
         c = self._create_test_cdr()
         self.dbapi.unregister_conductor(c.hostname)
         self.assertRaises(
-            exception.ConductorNotFound,
-            self.dbapi.get_conductor,
-            c.hostname)
+                exception.ConductorNotFound,
+                self.dbapi.get_conductor,
+                c.hostname)
         self.dbapi.touch_conductor(c.hostname)
         self.dbapi.get_conductor(c.hostname)
 
@@ -110,7 +115,7 @@ class DbConductorTestCase(base.DbTestCase):
         self.assertEqual('hostname2', node2.reservation)
         self.assertIsNone(node3.reservation)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_one_host_no_driver(self, mock_utcnow):
         h = 'fake-host'
         expected = {}
@@ -120,7 +125,7 @@ class DbConductorTestCase(base.DbTestCase):
         result = self.dbapi.get_active_driver_dict()
         self.assertEqual(expected, result)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_one_host_one_driver(self, mock_utcnow):
         h = 'fake-host'
         d = 'fake-driver'
@@ -131,7 +136,7 @@ class DbConductorTestCase(base.DbTestCase):
         result = self.dbapi.get_active_driver_dict()
         self.assertEqual(expected, result)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_one_host_many_drivers(self, mock_utcnow):
         h = 'fake-host'
         d1 = 'driver-one'
@@ -143,7 +148,7 @@ class DbConductorTestCase(base.DbTestCase):
         result = self.dbapi.get_active_driver_dict()
         self.assertEqual(expected, result)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_many_hosts_one_driver(self, mock_utcnow):
         h1 = 'host-one'
         h2 = 'host-two'
@@ -156,7 +161,7 @@ class DbConductorTestCase(base.DbTestCase):
         result = self.dbapi.get_active_driver_dict()
         self.assertEqual(expected, result)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_many_hosts_and_drivers(self, mock_utcnow):
         h1 = 'host-one'
         h2 = 'host-two'
@@ -172,7 +177,7 @@ class DbConductorTestCase(base.DbTestCase):
         result = self.dbapi.get_active_driver_dict()
         self.assertEqual(expected, result)
 
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
     def test_get_active_driver_dict_with_old_conductor(self, mock_utcnow):
         past = datetime.datetime(2000, 1, 1, 0, 0)
         present = past + datetime.timedelta(minutes=2)
@@ -200,20 +205,3 @@ class DbConductorTestCase(base.DbTestCase):
         expected = {d: set([h1, h2]), d1: set([h1]), d2: set([h2])}
         result = self.dbapi.get_active_driver_dict(interval=two_minute)
         self.assertEqual(expected, result)
-
-    @mock.patch.object(timeutils, 'utcnow', autospec=True)
-    def test_get_offline_conductors(self, mock_utcnow):
-        self.config(heartbeat_timeout=60, group='conductor')
-        time_ = datetime.datetime(2000, 1, 1, 0, 0)
-
-        mock_utcnow.return_value = time_
-        c = self._create_test_cdr()
-
-        # Only 30 seconds passed since last heartbeat, it's still
-        # considered alive
-        mock_utcnow.return_value = time_ + datetime.timedelta(seconds=30)
-        self.assertEqual([], self.dbapi.get_offline_conductors())
-
-        # 61 seconds passed since last heartbeat, it's dead
-        mock_utcnow.return_value = time_ + datetime.timedelta(seconds=61)
-        self.assertEqual([c.hostname], self.dbapi.get_offline_conductors())
